package com.emato.cus.supervise.biz.acqGoodsMoveSchedule.up;

import com.emato.cus.supervise.biz.CusWmsTask;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqGoodsMove;
import com.emato.cus.supervise.domainCus.CusAcqGoodsMove05;
import com.emato.cus.supervise.util.LocalDateTimeUtils;
import com.google.common.collect.Maps;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-03 15:21
 */
@Component
public class AcqGoodsMoveUpBiz implements CusWmsTask {
    private static final Logger logger = LoggerFactory.getLogger(AcqGoodsMoveUpBiz.class);

    @Autowired
    private AcqGoodsMoveUpRecordTime acqGoodsMoveUpRecordTime;

    @Autowired
    private AcqGoodsMoveUpWmsData acqGoodsMoveUpWmsData;

    @Autowired
    private AcqGoodsMoveUpCusData acqGoodsMoveUpCusData;

    @Autowired
    private AcqGoodsMoveUpDataConversion acqGoodsMoveUpDataConversion;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.ACQ_GOODS_MOVE_UP.getCode() + "]" + EmtRecordTimeEnum.ACQ_GOODS_MOVE_UP.getName();


    /**
     * 任务入口
     */
    @Override
    public void task() {

        // 获取扫描时间
        String oldThisTime = acqGoodsMoveUpRecordTime.getEmtRecordTime();
        if (StringUtils.isBlank(oldThisTime)) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】未获取到本次扫描时间, 本次扫描提前结束！！！");
            //下次扫描时间
            acqGoodsMoveUpRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;

        }

        // 扫描WMS 数据
        List<WmsAcqGoodsMove> wmsList = acqGoodsMoveUpWmsData.getWmsData(oldThisTime);
        if (wmsList == null || wmsList.size() == 0) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】获取到本次扫描数据为空, 不执行写数据操作, 本次扫描提前结束！！！");
            //下次扫描时间
            acqGoodsMoveUpRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;
        }
        Map params = Maps.newHashMap();
        params.put("wmsList",wmsList);
        //将wms数据转换cus
        List<CusAcqGoodsMove05> cusList = acqGoodsMoveUpDataConversion.conversion(params);

        // 写CUS 数据
        int res = acqGoodsMoveUpCusData.insertCus(cusList);

        // 更新扫描时间
        boolean bl = acqGoodsMoveUpRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                oldThisTime);

    }
}
