package com.emato.cus.supervise.biz.acqGoodsMoveSchedule.up;

import com.emato.cus.supervise.biz.WmsData;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqGoodsMove;
import com.emato.cus.supervise.service.wms.WmsAcqGoodsMoveService;
import com.google.common.collect.ImmutableMap;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

/**
 * 货物库位移动数据 业务 WMS
 * @author zengjunlin
 * @version 1.0
 * 2018-02-03 15:23
 */
@Component
public class AcqGoodsMoveUpWmsData implements WmsData {
    private static final Logger logger = LoggerFactory.getLogger(AcqGoodsMoveUpWmsData.class);

    @Autowired
    private WmsAcqGoodsMoveService wmsAcqGoodsMoveService;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.ACQ_GOODS_MOVE_UP.getCode() + "]" + EmtRecordTimeEnum.ACQ_GOODS_MOVE_UP.getName();


    @Override
    public List getWmsData(String thisTime) {
        logger.info("---------- 货物库位移动数据::获取本次监控数据开始 --------------------");

        if (StringUtils.isBlank(thisTime)) {
            String err = "---【" + DATA_TYPE_INFO + "】本次扫描时间为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        ImmutableMap param = ImmutableMap.of("thisTime", thisTime);
        List<WmsAcqGoodsMove> resultList = wmsAcqGoodsMoveService.getWmsAcqGoodsMoveUp(param);

        if (resultList == null || resultList.size() == 0) {
            String err = "---【" + DATA_TYPE_INFO + "】获取本次监控数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }
        logger.info("---【" + DATA_TYPE_INFO + "】获取本次监控数据{}条.", resultList.size());

        logger.info("---------- 货物库位移动数据::获取本次监控数据结束 --------------------");

        return resultList;
    }
}
