package com.emato.cus.supervise.biz.acqInventoryInfo;

import com.emato.cus.supervise.biz.CusWmsTask;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqInventoryInfo;
import com.emato.cus.supervise.domainCus.CusAcqInventoryInfo03;
import com.emato.cus.supervise.domainOms.OmsAcqInventoryInfo;
import com.emato.cus.supervise.util.GsonUtil;
import com.emato.cus.supervise.util.LocalDateTimeUtils;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * 企业库存信息业务
 *
 * @author zengjunlin
 * @version 1.0
 * 2018-02-01 16:29
 */
@Component
public class AcqInventoryInfoBiz implements CusWmsTask {

    private static final Logger logger = LoggerFactory.getLogger(AcqInventoryInfoBiz.class);

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getCode() + "]" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getName();

    @Autowired
    private AcqInventoryInfoRecordTime acqInventoryInfoRecordTime;

    @Autowired
    private AcqInventoryInfoWmsData acqInventoryInfoWmsData;

    @Autowired
    private AcqInventoryInfoCusData acqInventoryInfoCusData;

    @Autowired
    private AcqInventoryInfoDataConversion acqInventoryInfoDataConversion;

    @Autowired
    private AcqInventoryInfoOmsData acqInventoryInfoOmsData;

    /**
     * 任务入口
     */
    @Override
    public void task() {
        // 获取扫描时间
        String oldThisTime = acqInventoryInfoRecordTime.getEmtRecordTime();
        if (StringUtils.isBlank(oldThisTime)) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】未获取到本次扫描时间, 本次扫描提前结束！！！");
            //下次扫描时间
            acqInventoryInfoRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;

        }

        // 扫描WMS 数据
        List<WmsAcqInventoryInfo> wmsList = acqInventoryInfoWmsData.getWmsData(oldThisTime);
        if (wmsList == null || wmsList.size() == 0) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】获取到本次扫描WMS数据为空, 不执行写数据操作, 本次扫描提前结束！！！");
            //下次扫描时间
            acqInventoryInfoRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;
        }
        List<String> merchSnList = Lists.newArrayList();

        wmsList.forEach(i -> merchSnList.add(i.getMerchSn()));

        // 根据sku查询oms系统数据。
        List<OmsAcqInventoryInfo> omsList = acqInventoryInfoOmsData.getOmsData(merchSnList);

        if (omsList == null || omsList.isEmpty()) {
            logger.error("wms扫描到的数据" + GsonUtil.toJson(wmsList));
            logger.info("--- 【" + DATA_TYPE_INFO + "】获取到本次扫描OMS数据为空, 不执行写数据操作, 本次扫描提前结束！！！");
            //下次扫描时间
            acqInventoryInfoRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;
        }
        Map params = Maps.newHashMap();
        params.put("wmsList", wmsList);
        params.put("omsList", omsList);

        //oms和wms数据，转成海关数据
        List<CusAcqInventoryInfo03> cusAcqInventoryInfo03List = acqInventoryInfoDataConversion.conversion(params);

        // 写CUS 数据
        int res = acqInventoryInfoCusData.insertCus(cusAcqInventoryInfo03List);

        // 更新扫描时间
        boolean bl = acqInventoryInfoRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                oldThisTime);
    }


}
