package com.emato.cus.supervise.biz.acqInventoryInfo;

import com.emato.cus.supervise.biz.RecordTime;
import com.emato.cus.supervise.constant.CommonConstant;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domainCus.EmtRecordTime;
import com.emato.cus.supervise.service.cus.EmtRecordTimeService;
import com.emato.cus.supervise.util.LocalDateTimeUtils;
import com.google.common.collect.ImmutableMap;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-01 16:43
 */
@Component
public class AcqInventoryInfoRecordTime implements RecordTime {

    private static final Logger logger = LoggerFactory.getLogger(AcqInventoryInfoRecordTime.class);

    @Autowired
    private EmtRecordTimeService emtRecordTimeService;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getCode() + "]" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getName();

    /**
     * 获取扫描时间
     *
     * @return
     */
    @Override
    public String getEmtRecordTime() {
        logger.info("---------- 货物库存数据::获取上次扫描时间开始 --------------------");

        //根据数据类型, 取扫描时间
        Map<String, Object> param = ImmutableMap.of("dataType", EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getCode());

        List<EmtRecordTime> list = emtRecordTimeService.selectEmtRecordTime(param);
        if (list == null || list.size() == 0) {
            String err = "---【" + DATA_TYPE_INFO + "】取扫描时间数据为空.";
            logger.error(err);
            return null;
        }

        String oldLastTime = list.get(0).getLastTime();
        String oldThisTime = list.get(0).getThisTime();

        logger.info("---【" + DATA_TYPE_INFO + "】任务上次扫描时间:{}", oldLastTime);
        logger.info("---【" + DATA_TYPE_INFO + "】任务本次扫描时间:{}", oldThisTime);

        logger.info("---------- 货物库存数据::获取上次扫描时间结束 --------------------");
        return oldThisTime;
    }
    /**
     * 更新记录时间
     *
     * @param thisTime 当前时间作为下次扫描时间
     * @param lastTime 本次扫描时间成为上次扫描时间
     * @return
     */
    @Override
    public boolean updateWmsRecordTime(String thisTime, String lastTime) {
        logger.info("---------- 货物库存数据::更新扫描时间开始 --------------------");

        if (StringUtils.isBlank(thisTime)) {
            thisTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        }
        if (StringUtils.isBlank(lastTime)) {
            logger.info("---【" + DATA_TYPE_INFO + "】本次更新时间为空, 不能写入扫描时间表, 更新扫描时间提前结束.");
            return false;
        }

        logger.info("---【" + DATA_TYPE_INFO + "】本次扫描时间为:{}, 下次扫描时间:{}.", lastTime, thisTime);


        ImmutableMap.Builder builder = new ImmutableMap.Builder();
        builder.put("dataType", EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getCode());
        builder.put("lastTime", lastTime);
        builder.put("thisTime", thisTime);
        builder.put("moderSn", CommonConstant.moderSn);
        builder.put("modTime", LocalDateTime.now());

        int res = emtRecordTimeService.updateEmtRecordTime(builder.build());
        String err = "---【" + DATA_TYPE_INFO + "】更新扫描时间'{" + (res == 1 ? "成功" : "失败, 结束本次扫描!!!") + "}'.";
        logger.info(err);
        if (res != 1) {
            return false;
        }

        logger.info("---------- 货物库存数据::更新扫描时间结束 --------------------");

        return res == 1;
    }
}
