package com.emato.cus.supervise.biz.acqInventoryInfo;

import com.emato.cus.supervise.biz.WmsData;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqInventoryInfo;
import com.emato.cus.supervise.service.wms.WmsAcqInventoryInfoService;
import com.google.common.collect.ImmutableMap;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-02 09:28
 */
@Component
public class AcqInventoryInfoWmsData implements WmsData {

    private static final Logger logger = LoggerFactory.getLogger(AcqInventoryInfoWmsData.class);

    @Autowired
    private WmsAcqInventoryInfoService wmsAcqInventoryInfoService;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getCode() + "]" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getName();


    @Override
    public List getWmsData(String thisTime) {
        logger.info("---------- 货物库存数据::获取本次监控数据开始 --------------------");

        if (StringUtils.isBlank(thisTime)) {
            String err = "---【" + DATA_TYPE_INFO + "】本次扫描时间为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        ImmutableMap param = ImmutableMap.of("thisTime", thisTime);
        List<WmsAcqInventoryInfo> resultList = wmsAcqInventoryInfoService.getWmsAcqInventoryInfo(param);

        if (resultList == null || resultList.size() == 0) {
            String err = "---【" + DATA_TYPE_INFO + "】获取本次监控数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        logger.info("---【" + DATA_TYPE_INFO + "】获取本次监控数据{}条.", resultList.size());

        logger.info("---------- 货物库存数据::获取本次监控数据结束 --------------------");

        return resultList;
    }


}
