package com.emato.cus.supervise.biz.acqShelfLoad.down;

import com.emato.cus.supervise.biz.WmsData;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqShelfLoad;
import com.emato.cus.supervise.service.wms.WmsAcqShelfLoadService;
import com.google.common.collect.ImmutableMap;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

/**
 * 货物上下架数据 下架 WMS
 * @author Scott Chen
 * @version 1.0
 * 2017-10-31 12:24
 */
@Component
public class AcqShelfLoadDownWmsData implements WmsData {
    private static final Logger logger = LoggerFactory.getLogger(AcqShelfLoadDownWmsData.class);

    @Autowired
    private WmsAcqShelfLoadService wmsAcqShelfLoadService;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.ACQ_SHELF_LOAD_DOWN.getCode() + "]" + EmtRecordTimeEnum.ACQ_SHELF_LOAD_DOWN.getName();


    @Override
    public List getWmsData(String thisTime) {
        logger.info("---------- 货物上下架数据::下架::获取本次监控数据开始 --------------------");

        if (StringUtils.isBlank(thisTime)) {
            String err = "---【" + DATA_TYPE_INFO + "】本次扫描时间为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        ImmutableMap param = ImmutableMap.of("thisTime", thisTime);
        List<WmsAcqShelfLoad> resultList = wmsAcqShelfLoadService.getWmsAcqShelfLoadDown(param);

        if (resultList == null || resultList.size() == 0) {
            String err = "---【" + DATA_TYPE_INFO + "】获取本次监控数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }
        logger.info("---【" + DATA_TYPE_INFO + "】获取本次监控数据{}条.", resultList.size());

        logger.info("---------- 货物上下架数据::下架::获取本次监控数据结束 --------------------");

        return resultList;
    }
}
