package com.emato.cus.supervise.biz.acqShelfLoad.up;

import com.emato.cus.supervise.biz.CusWmsTask;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqShelfLoad;
import com.emato.cus.supervise.domainCus.CusAcqShelfLoad04;
import com.emato.cus.supervise.util.LocalDateTimeUtils;
import com.google.common.collect.Maps;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-03 11:25
 */
@Component
public class AcqShelfLoadUpBiz implements CusWmsTask{

    private static final Logger logger = LoggerFactory.getLogger(AcqShelfLoadUpBiz.class);

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.ACQ_SHELF_LOAD.getCode() + "]" + EmtRecordTimeEnum.ACQ_SHELF_LOAD.getName();

    @Autowired
    private AcqShelfLoadUpRecordTime acqShelfLoadUpRecordTime;

    @Autowired
    private AcqShelfLoadUpCusData acqShelfLoadUpCusData;

    @Autowired
    private AcqShelfLoadUpWmsData acqShelfLoadUpWmsData;

    @Autowired
    private AcqShelfLoadUpDataConversion acqShelfLoadUpDataConversion;

    /**
     * 任务入口
     */
    @Override
    public void task() {
        // 获取扫描时间
        String oldThisTime = acqShelfLoadUpRecordTime.getEmtRecordTime();
        if (StringUtils.isBlank(oldThisTime)) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】未获取到本次扫描时间, 本次扫描提前结束！！！");
            //下次扫描时间
            acqShelfLoadUpRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;

        }

        // 扫描WMS 数据
        List<WmsAcqShelfLoad> wmsList = acqShelfLoadUpWmsData.getWmsData(oldThisTime);
        if (wmsList == null || wmsList.size() == 0) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】获取到本次扫描数据为空, 不执行写数据操作, 本次扫描提前结束！！！");
            //下次扫描时间
            acqShelfLoadUpRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;
        }
        Map params = Maps.newHashMap();
        params.put("wmsList",wmsList);
        //组装CUS 数据
        List<CusAcqShelfLoad04> cusList = acqShelfLoadUpDataConversion.conversion(params);

        // 写CUS 数据
        int res = acqShelfLoadUpCusData.insertCus(cusList);

        // 更新扫描时间
        boolean bl = acqShelfLoadUpRecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                oldThisTime);
    }
}
