package com.emato.cus.supervise.config.ds.second;

import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.SqlSessionTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.jdbc.DataSourceProperties;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.PropertyResolver;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

/**
 * 多数据源配置
 *
 * 数据源配置
 *
 * 指定mybatis-config.xml, 和要扫描的别名包
 *
 * @author Scott Chen
 * @date 2017/4/22
 */
@Configuration
public class SecondDataSourceConfig {

    @Autowired
    private PropertyResolver propertyResolver;

    @Bean
    public DataSource secondDataSource() {
        return secondDataSourceProperties().initializeDataSourceBuilder().build();
    }

    @Bean
    @ConfigurationProperties(prefix = "spring.datasource.second")
    public DataSourceProperties secondDataSourceProperties() {
        return new DataSourceProperties();
    }

    @Bean
    public SqlSessionFactory secondSqlSessionFactory(DataSource secondDataSource) throws Exception  {
        SqlSessionFactoryBean sessionFactoryBean = new SqlSessionFactoryBean();
        sessionFactoryBean.setDataSource(secondDataSource);
        //Mybatis XML配置文件
        sessionFactoryBean.setConfigLocation(new PathMatchingResourcePatternResolver().getResource(
                propertyResolver.getProperty("mybatis.second.config-location")));
        sessionFactoryBean.setTypeAliasesPackage(propertyResolver.getProperty("mybatis.second.type-aliases-package"));
        //sessionFactoryBean.setMapperLocations(mapperLocations());
        return sessionFactoryBean.getObject();
    }

    @Bean
    public DataSourceTransactionManager secondTransactionManager(DataSource secondDataSource) {
        return new DataSourceTransactionManager(secondDataSource);
    }

    @Bean
    public SqlSessionTemplate secondSqlSessionTemplate(SqlSessionFactory secondSqlSessionFactory) {
        return new SqlSessionTemplate(secondSqlSessionFactory);
    }

    /*private Resource[] mapperLocations(){
        Resource resource = new PathMatchingResourcePatternResolver().getResource("classpath:mybatis/mapper*//*.xml");
        return ImmutableSet.of(resource).stream().toArray(Resource[]::new);
    }*/

}
