package com.emato.cus.supervise.msg;

import com.google.common.base.Strings;

import java.util.List;

/**
 * @author Scott Chen
 * @date 2017/4/20
 */
public class ResponseMessage {

    private static final String SUCCESS_CODE = "0";
    private static final String SUCCESS_MSG = "成功";

    public static final String ERROR_CODE = "-1";
    public static final String ERROR_MSG = "错误";

    private static final String FAILURE_CODE = "-2";
    private static final String FAILURE_MSG = "失败";

    private String code;
    private String msg;
    private ResponseMessageData data;

    private ResponseMessage() {
    }

    public String getCode() {
        return code;
    }

    public String getMsg() {
        return msg;
    }

    public ResponseMessageData getData() {
        return data;
    }

    public static Builder builder() {
        return new Builder();
    }
    public static Builder builder(String code, String msg) {
        return new Builder(code, msg);
    }
    public static Builder builder(String code, String msg, ResponseMessageData responseMessageData) {
        return new Builder(code, msg, responseMessageData);
    }
    public static Builder builder(String code, String msg, List list) {
        return new Builder(code, msg, list);
    }

    //---------- 直接返回结果 ----------
    //成功
    public static ResponseMessage success() {
        return new Builder().build();
    }
    public static ResponseMessage success(String code, String msg) {
        return new Builder(code, msg).build();
    }
    public static ResponseMessage success(String msg) {
        return new Builder(SUCCESS_CODE, msg).build();
    }
    public static ResponseMessage success(String msg, List rows) {
        return new Builder(SUCCESS_CODE, msg, rows).build();
    }
    public static ResponseMessage success(String code, String msg, List rows) {
        return new Builder(code, msg, rows).build();
    }
    public static ResponseMessage success(List rows) {
        return new Builder(SUCCESS_CODE, SUCCESS_MSG, rows).build();
    }

    //错误
    public static ResponseMessage error() {
        return new Builder(ERROR_CODE, ERROR_MSG).build();
    }
    public static ResponseMessage error(String code, String msg) {
        return new Builder(code, msg).build();
    }
    public static ResponseMessage error(String msg) {
        return new Builder(ERROR_CODE, msg).build();
    }
    public static ResponseMessage error(List rows) {
        return new Builder(ERROR_CODE, ERROR_MSG, rows).build();
    }
    public static ResponseMessage error(String code, String msg, List rows) {
        return new Builder(code, msg, rows).build();
    }

    //失败
    public static ResponseMessage failed() {
        return new Builder(FAILURE_CODE, FAILURE_MSG).build();
    }
    public static ResponseMessage failed(String code, String msg) {
        return new Builder(code, msg).build();
    }
    public static ResponseMessage failed(String msg) {
        return new Builder(FAILURE_CODE, msg).build();
    }
    public static ResponseMessage failed(List rows) {
        return new Builder(FAILURE_CODE, FAILURE_MSG, rows).build();
    }
    public static ResponseMessage failed(String code, String msg, List rows) {
        return new Builder(code, msg, rows).build();
    }

    /**
     * 消息构建器类
     */
    public static class Builder {
        private String code;
        private String msg;
        private ResponseMessageData data;

        public Builder() {
            this.code = SUCCESS_CODE;
            this.msg = SUCCESS_MSG;
            this.data = ResponseMessageData.builder().build();
        }

        public Builder(String code, String msg) {
            this.code = Strings.isNullOrEmpty(code) ? SUCCESS_CODE : code;
            this.msg = Strings.isNullOrEmpty(msg) ? SUCCESS_MSG : msg;
            this.data = ResponseMessageData.builder().build();
        }

        public Builder(String code, String msg, ResponseMessageData responseMessageData) {
            this.code = code;
            this.msg = msg;
            this.data = responseMessageData;
        }

        public Builder(String code, String msg, List rows) {
            this.code = code;
            this.msg = msg;
            this.data = ResponseMessageData.builder(rows).build();
        }

        public Builder setCode(String code) {
            this.code = code;
            return this;
        }

        public Builder setMsg(String msg) {
            this.msg = msg;
            return this;
        }

        public Builder setData(ResponseMessageData data) {
            this.data = data;
            return this;
        }

        public ResponseMessage build() {
            ResponseMessage message = new ResponseMessage();
            message.code = this.code;
            message.msg = this.msg;
            message.data = this.data;
            return message;
        }

    }
}

