package com.emato.cus.supervise.schedule;

import com.emato.cus.supervise.biz.acqShelfLoad.down.AcqShelfLoadDownBiz;
import com.emato.cus.supervise.biz.acqShelfLoad.up.AcqShelfLoadUpBiz;
import com.emato.cus.supervise.util.LocalDateTimeUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

/**
 *
 * @Configuration
 * @EnableScheduling
 * @author zengjunlin
 * @version 1.0
 * 2018-02-03 11:11
 */
@Configuration
@EnableScheduling
public class AcqShelfLoadSchedule {

    private static final Logger logger = LoggerFactory.getLogger(AcqShelfLoadSchedule.class);

    @Autowired
    private AcqShelfLoadUpBiz acqShelfLoadUpBiz;

    @Autowired
    private AcqShelfLoadDownBiz acqShelfLoadDownBiz;

    /**
     * 上架
     */
    //每月1号开始,每天10,18点执行各1次,共2次
    @Scheduled(cron = "0 0 10,18 1/1 * ?")
    public void timerUp() {
        logger.info("==================== 货物上下架数据::上架::监控数据读取开始 ====================");
        String begDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务开始时间: {}", begDateTime);

        acqShelfLoadUpBiz.task();

        String endDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务结束时间: {}", endDateTime);
        logger.info("==================== 货物上下架数据::上架::监控数据读取结束 ====================");

    }

    /**
     * 下架
     */
    //每月1号开始,每天18点执行1次,共1次
    @Scheduled(cron = "0 0 18 1/1 * ?")
    public void timerDown() {
        logger.info("==================== 货物上下架数据::下架::监控数据读取开始 ====================");
        String begDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务开始时间: {}", begDateTime);

        acqShelfLoadDownBiz.task();

        String endDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务结束时间: {}", endDateTime);
        logger.info("==================== 货物上下架数据::下架::监控数据读取结束 ====================");

    }


}
